#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <qapplication.h>
#include "QtProgress.h"

using namespace std;

MyProgress::MyProgress(QWidget* parent,string text):myprog(0),compute(true),label(text),parent(parent) {}

MyProgress::~MyProgress() {
  if (myprog!=0) delete myprog;
}

bool MyProgress::progress_handler(int i,int j) {
  if (myprog==0) {
    myprog = new QProgressDialog(label.c_str(), "Cancel", 10, parent, "progress", true);
    connect(myprog, SIGNAL(cancelled()), this, SLOT(stopCompute()));
    myprog->show();
  }
  myprog->setTotalSteps(j);
  myprog->setProgress (i);
  qApp->processEvents();
  return compute;
}
void MyProgress::stopCompute(){
  stop();
  compute=false;
}
